Summary: The Blosc metacompressor
Name: blosc
Version: 1.2.3
Release: 1%{?dist}
License: MIT
Group: System Environment/Libraries
Source: http://blosc.org/sources/%{version}/%{name}-%{version}.tar.gz
URL:  http://blosc.pytables.org/trac
BuildRequires: cmake

%description
High performance compressor optimized for binary data. 
It has been designed to transmit data to the processor cache 
faster than the traditional, non-compressed, direct memory fetch 
approach via a memcpy() OS call. Blosc is the first compressor 
(that I'm aware of) that is meant not only to reduce the size of 
large datasets on-disk or in-memory, but also to accelerate 
memory-bound computations 

%package devel
Summary: Header files and libraries for Blosc development
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The blosc-devel package contains the header files and libraries needed
to develop programs that use the blosc meta-compressor.

%package static
Summary: Static libraries for Blosc development
Group: Development/Libraries
Requires: %{name}-devel = %{version}-%{release}

%description static
The blosc-static package includes static libraries needed
to develop programs that use the blosc meta-compressor

%prep
%setup -q

# Use the proper library path and SSE2 instruction on 64bits systems
%ifarch x86_64
cmake %{?_cmake_lib_suffix64} \
    -DCMAKE_C_FLAGS:STRING="%{optflags} -msse2" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DTEST_INCLUDE_BENCH_SUITE:BOOL=OFF .
%else
cmake -DCMAKE_C_FLAGS:STRING="%{optflags}" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DTEST_INCLUDE_BENCH_SUITE:BOOL=OFF .
%endif

%build
make VERBOSE=1 %{?_smp_mflags}

%check
make test VERBOSE=1

%install
rm -rf ${RPM_BUILD_ROOT}

make install DESTDIR=${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}/%{_docdir}/bench
cp -pr bench/plot-speeds.py* ${RPM_BUILD_ROOT}/%{_docdir}/bench
cp -pr bench/*.c ${RPM_BUILD_ROOT}/%{_docdir}/bench

%clean
rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc README.rst ANNOUNCE.rst RELEASE_NOTES.rst README_HEADER.rst README_THREADED.rst RELEASING.rst
%{_libdir}/libblosc.so.*

%files devel
%{_libdir}/libblosc.so
%{_includedir}/blosc.h
%{_docdir}/bench/plot-speeds.py*
%{_docdir}/bench/*.c

%files static
%doc README.rst
%{_libdir}/libblosc.a

%changelog
* Fri Sep 20 2013 Thibault North <tnorth@fedoraproject.org> - 1.2.3-1
- Sync upstream

* Fri Mar 22 2013 Thibault North <tnorth@fedoraproject.org> - 1.1.6-1
- Initial package
